@@ -5,12 +5,21 @@
 	ObjectDescriptor has information necessary to construct and store
 	the objects described by csync messages
 */
+
+typedef	void ObjectStoreFunc _PROTO((void *, Empire_Database *, struct genobject *));
+typedef	struct genobject *ObjectFindFunc _PROTO((void *, Empire_Database *, struct genobject *));
+
+
 typedef struct {
 	long objtype;
 	char *objdescr;
 	int objsize;
 	struct castr *obj_ca;
-	void (*store) _PROTO((Empire_Database *,void *));
+	ObjectStoreFunc *store;
+	ObjectFindFunc *find;
+	int collection_offset;	/* field offset in edb of collection */
+	int index_offset;	/* field offset in edb of index */
+	int key1, key2;		/* field offset in structure of keys */
 } ObjectDescriptor;
 
 /*
@@ -33,15 +42,5 @@ typedef struct DictionaryStruct {
 	ObjectDescriptor *objdesc;
 } Dictionary;
 
-#define EPROC(X) extern void X _PROTO((Empire_Database *, struct genobject *))
-
-EPROC(sect_ca_store);
-EPROC(sect_cf_store);
-EPROC(land_ca_store);
-EPROC(land_cf_store);
-EPROC(ship_ca_store);
-EPROC(ship_cf_store);
-EPROC(plane_ca_store);
-EPROC(plane_cf_store);
 
 #endif
